use std::fs;
use std::path;

use regex::Regex;

#[derive(Debug)]
pub struct Post {
    pub title: String,
    pub body: String,
    pub slug: String,
}

pub fn parse_post(path: path::PathBuf) -> Post {
    let contents = fs::read_to_string(&path).expect("Couldn't read post file");

    lazy_static! {
        static ref re: Regex = Regex::new(r"^# (?P<title>.*)\n\n(?P<body>.*)").unwrap();
        static ref slug_re: Regex = Regex::new(r"(?P<slug>\S+).md").unwrap();
    }

    let title = &re.captures(&contents).expect("Couldn't parse title")["title"];
    let body = &re.captures(&contents).expect("Couldn't parse body")["body"];

    let filename = &path.file_name().unwrap().to_str().unwrap();
    let slug = &slug_re.captures(filename).expect("Couldn't parse slug")["slug"];
    Post {
        title: String::from(title),
        body: String::from(body),
        slug: String::from(slug),
    }
}
